#
# spec file for package alsa-utils
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define build_from_git 0
%define do_autoreconf 0
%define _udevdir %(pkg-config --variable=udevdir udev)
%ifarch %ix86 x86_64 %arm aarch64 ppc64le riscv64
%define enable_topology	1
%else
%define enable_topology	0
%endif

Name:           alsa-utils
Version:        1.2.14
Release:        1.1
Summary:        Advanced Linux Sound Architecture Utilities
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            http://www.alsa-project.org/
%if 0%{?build_from_git}
Source:         https://www.alsa-project.org/files/pub/utils/alsa-utils-%{version}.tar.bz2
Source1:        https://www.alsa-project.org/files/pub/utils/alsa-utils-%{version}.tar.bz2.sig
%else
Source:         alsa-utils-%{version}.tar.bz2
%endif
Source2:        01beep.conf
Source3:        sound-extra.service
Source5:        load-sound-modules.sh
# from https://www.alsa-project.org/files/pub/gpg-release-key-v1.txt
Source6:        alsa-utils.keyring
# upstream fixes
# downstream fixes
Patch100:       alsa-info-no-update-for-distro-script.patch
Patch101:       alsa-utils-configure-version-revert.patch
BuildRequires:  alsa-devel
%if %enable_topology
BuildRequires:  alsa-topology-devel
%endif
BuildRequires:  fftw3-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
%if 0%{?suse_version} < 1500
BuildRequires:  python-docutils
%else
BuildRequires:  python3-docutils
%endif
BuildRequires:  xmlto
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
%if 0%{?do_autoreconf} || 0%{?build_from_git}
BuildRequires:  automake
BuildRequires:  libtool
%endif
Requires:       alsa
# for alsa-info.sh
Requires:       dialog
Requires:       pciutils
Requires:       tree

%description
This package contains utility programs supporting ALSA, Advanced Linux
Sound Architecture.

%package -n alsabat
Summary:        Command-line sound tester for ALSA sound card driver
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       alsa-utils = %{version}

%description -n alsabat
BAT (Basic Audio Tester) is a simple command-line utility intended
to help automate audio driver and sound server testing with little human
interaction. BAT can be used to test audio quality, stress test features
and test audio before and after PM state changes.

%prep
%setup -q
%patch -P 100 -p1
%if 0%{?do_autoreconf} || 0%{?build_from_git}
%patch -P 101 -p1
# fix stupid automake's automatic action
sed -i -e's/EXTRA_DIST= config.rpath /EXTRA_DIST=/' Makefile.am
%endif

%build
export AUTOMAKE_JOBS="%{?_smp_mflags}"
%if 0%{?build_from_git}
export GITCOMPILE_NO_MAKE=1
./gitcompile --with-curses=ncursesw \
  --with-systemdsystemunitdir=%{_unitdir} \
  --with-udev-rules-dir=%{_udevdir}/rules.d \
  --with-alsactl-lock-dir=/run/lock
%else
%if 0%{?do_autoreconf}
gettextize -c -f --no-changelog
autoreconf -fi
%endif
%configure --with-curses=ncursesw \
  --with-systemdsystemunitdir=%{_unitdir} \
  --with-udev-rules-dir=%{_udevdir}/rules.d \
  --with-alsactl-lock-dir=/run/lock
%endif
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_datadir}/alsa/init/preinit
mkdir -p %{buildroot}%{_datadir}/alsa/init/postinit
%if %enable_topology
rm -f %{_libdir}/alsa-topology/*.la
%endif
for i in %{_sourcedir}/[0-9]*.conf; do
  install -c -m 0644 $i %{buildroot}%{_datadir}/alsa/init/postinit
done
# remove obsoleted alsaconf script
rm -f %{buildroot}%{_sbindir}/alsaconf
rm -f %{buildroot}%{_datadir}/locale/*/*/alsaconf.mo
rm -f %{buildroot}%{_mandir}/*/man*/alsaconf.*
rm -f %{buildroot}%{_mandir}/man*/alsaconf.*
rmdir --ignore-fail-on-non-empty -p %{buildroot}%{_mandir}/*/man* %{buildroot}%{_mandir}/man*
%find_lang %{name} --all-name
ln -s alsa-restore.service %{buildroot}%{_unitdir}/alsasound.service
mkdir -p %{buildroot}%{_localstatedir}/lib/alsa
# systemd unit files
install -c -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}
ln -s ../sound-extra.service %{buildroot}%{_unitdir}/sound.target.wants
mkdir -p %{buildroot}%{_prefix}/lib/systemd/scripts
install -c -m 0755 %{SOURCE5} %{buildroot}%{_prefix}/lib/systemd/scripts

%pre
%service_add_pre sound-extra.service

%post
%service_add_post sound-extra.service
# migrate the old asound.state
if [ ! -f %{_localstatedir}/lib/alsa/asound.state ]; then
  test -f /etc/asound.state && \
    cp -a /etc/asound.state %{_localstatedir}/lib/alsa/asound.state
fi
exit 0

%preun
%service_del_preun sound-extra.service

%postun
%service_del_postun sound-extra.service

%files -f %{name}.lang
%license COPYING
%doc README.md
%doc seq/aconnect/README*
%doc seq/aseqnet/README*
%{_mandir}/man*/*
%{_bindir}/*
%{_sbindir}/*
%exclude %{_bindir}/alsabat
%exclude %{_sbindir}/alsabat-test.sh
%if %enable_topology
%{_libdir}/alsa-topology
%endif
%exclude %{_mandir}/man*/alsabat.*
%{_datadir}/sounds/alsa
%{_datadir}/alsa
%{_udevdir}
%{_unitdir}/*.service
%{_unitdir}/sound.target.wants
%{_prefix}/lib/systemd/scripts
%{_localstatedir}/lib/alsa

%files -n alsabat
%license COPYING
%{_bindir}/alsabat
%{_sbindir}/alsabat-test.sh
%{_mandir}/man*/alsabat.*

%changelog
* Tue Apr 15 2025 Takashi Iwai <tiwai@suse.com>
- Update to alsa-utils 1.2.14:
  * alsactl: info updates
  * Man page fixes
  * alsactl: AMD acp-pdm-mach link
  * alsa-info.sh: Add alsa-ucm package to package filter
  * Topology: NHLT: Intel: Improve error message for DMIC enable conflict
  * Topology: NHLT: Intel: Fix mono DMIC configure for MTL platform
  * Topology: NHLT: Intel: Fix DMA slots config in SSP blob
  * amixer: fix unknown TVL sequence print
  * arecordmidi2: fix unitialization variable error in read_ump_raw()
  * aseqdump: Fix typos in messages
  For details, see:
    https://www.alsa-project.org/wiki/Changes_v1.2.13_v1.2.14#alsa-utils
- Drop obsoleted patches:
  0001-alsactl-90-alsa-restore.rules-fix-alsa_restore_go-st.patch
  0002-alsactl-90-alsa-restore.rules-fix-AMD-acp-pdm-mach-l.patch
* Wed Nov 20 2024 Takashi Iwai <tiwai@suse.com>
- Yet another fix for alsactl for AMD acp dmic:
  0002-alsactl-90-alsa-restore.rules-fix-AMD-acp-pdm-mach-l.patch
* Thu Nov 14 2024 Takashi Iwai <tiwai@suse.com>
- Fix alsactl restore error (bsc#1233353):
  0001-alsactl-90-alsa-restore.rules-fix-alsa_restore_go-st.patch
* Tue Nov 12 2024 Takashi Iwai <tiwai@suse.com>
- Update to alsa-utils 1.2.13:
  * alsactl: add support for AMD ACP digital microphone
  * aplay: Print '=== PAUSE ===' only if it is supported
  * aplaymidi/arecordmidi: Allow to pass 0 to -u option, too
  * new aplaymidi2/arecordmidi2 for MIDI v2.0
  * aseqdump: improved UMP supports
  * various topology updates
  * aseqsend: improvement and UMP supports
  For details, see:
    https://www.alsa-project.org/wiki/Changes_v1.2.12_v1.2.13#alsa-utils
* Thu Jun 13 2024 Takashi Iwai <tiwai@suse.com>
- Update to alsa-utils 1.2.12:
  * alsactl: NULL pointer fix
  * alsa-info.sh: log SoundWire devices reported in ACPI
  * alsamixer: fix calculation in set_normalized_volume (overflow)
  * topology: nhlt fixes
  * aplay: fix S24_LE wav header
  * aseqdump: Add dump for UMP Utility and System messages
  * Addition of aseqsend
  For details, see:
    https://www.alsa-project.org/wiki/Changes_v1.2.11_v1.2.12#alsa-utils
* Thu May 30 2024 Antonio Larrosa <alarrosa@suse.com>
- Require tree which is used by alsa-info.sh (bsc#1225665)
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Feb  2 2024 Takashi Iwai <tiwai@suse.com>
- Update to alsa-utils 1.2.11:
  * alsactl buffer overflow fix
  * alsatplg updates, NHLT ACPI parser updates
  * use smaller periods for speaker-test
  * add bandwidth-limited pink noise for speaker-test
  * aplay updates, including subformat extensions
  * compile warning fixes
  For details, see:
    https://www.alsa-project.org/wiki/Changes_v1.2.10_v1.2.11#alsa-utils
- Drop obsoleted patches:
  0001-axfer-use-ATTRIBUTE_UNUSED-instead-remove-argument-n.patch
  0002-amidi-use-ATTRIBUTE_UNUSED-instead-remove-argument-n.patch
  0003-alsaloop-use-ATTRIBUTE_UNUSED-instead-remove-argumen.patch
  0004-bat-use-ATTRIBUTE_UNUSED-instead-remove-argument-nam.patch
  0005-seq-use-ATTRIBUTE_UNUSED-instead-remove-argument-nam.patch
  0006-alsaucm-use-ATTRIBUTE_UNUSED-instead-remove-argument.patch
  0007-topology-use-ATTRIBUTE_UNUSED-instead-remove-argumen.patch
  0008-topology-include-locale.h.patch
  0009-nhlt-dmic-info.c-include-sys-types.h.patch
  0010-topology-pre-processor-Add-support-for-enum-controls.patch
  0011-configure.ac-fix-UMP-support-detection.patch
  0012-bat-really-skip-analysis-of-the-first-period-and-upd.patch
  0013-topology-add-include-for-ENABLE_NLS-on-musl.patch
  0014-nhlt-use-stdint.h-types.patch
  0015-Revert-nhlt-dmic-info.c-include-sys-types.h.patch
  0016-aplay-use-stdint.h-types-instead-u_int-u_short-u_cha.patch
  0017-alsa-restore.rules-use-devnode-instead-number-atribu.patch
  0018-nhlt-Revert-SSP_ANALOG-device_type-field.patch
  0019-alsactl-fix-potential-buffer-overwrite.patch
  0020-aplay-fix-buffer-overflow-and-tainted-format-string.patch
  0021-misc-fix-incorrect-usages-of-strerror.patch
  0022-aplay-Add-option-for-specifying-subformat.patch
  0023-aplay-allow-to-compile-with-older-alsa-lib-subformat.patch
  0024-aplay-log-pcm-status-before-reporting-a-fatal-error.patch
  0025-aplay-enable-timestamps-by-default.patch
  0026-aplay-status-dumps-are-called-only-in-verbose-mode.patch
  0027-aplaymidi-Set-event-completely-for-tempo-event.patch
* Mon Jan  8 2024 Takashi Iwai <tiwai@suse.com>
- Backport upstream fixes:
  buffer overflow fixes in aplay, segfault in aplaymidi, etc:
  0008-topology-include-locale.h.patch
  0009-nhlt-dmic-info.c-include-sys-types.h.patch
  0010-topology-pre-processor-Add-support-for-enum-controls.patch
  0011-configure.ac-fix-UMP-support-detection.patch
  0012-bat-really-skip-analysis-of-the-first-period-and-upd.patch
  0013-topology-add-include-for-ENABLE_NLS-on-musl.patch
  0014-nhlt-use-stdint.h-types.patch
  0015-Revert-nhlt-dmic-info.c-include-sys-types.h.patch
  0016-aplay-use-stdint.h-types-instead-u_int-u_short-u_cha.patch
  0017-alsa-restore.rules-use-devnode-instead-number-atribu.patch
  0018-nhlt-Revert-SSP_ANALOG-device_type-field.patch
  0019-alsactl-fix-potential-buffer-overwrite.patch
  0020-aplay-fix-buffer-overflow-and-tainted-format-string.patch
  0021-misc-fix-incorrect-usages-of-strerror.patch
  0022-aplay-Add-option-for-specifying-subformat.patch
  0023-aplay-allow-to-compile-with-older-alsa-lib-subformat.patch
  0024-aplay-log-pcm-status-before-reporting-a-fatal-error.patch
  0025-aplay-enable-timestamps-by-default.patch
  0026-aplay-status-dumps-are-called-only-in-verbose-mode.patch
  0027-aplaymidi-Set-event-completely-for-tempo-event.patch
* Mon Sep  4 2023 Takashi Iwai <tiwai@suse.com>
- Update to alsa-utils 1.2.10 (jsc#PED-6566):
  * MIDI 2.0 / UMP support for sequencer programs
  * nhlt: add nhlt-dmic-info utility
  * Build fixes and cleanups
  * speaker-test: allow large buffer and period time setup - up to 100 seconds
  * various topology fixes
  For details, see:
  https://www.alsa-project.org/wiki/Changes_v1.2.9_v1.2.10#alsa-utils
- Fix the builds with old gcc:
  0001-axfer-use-ATTRIBUTE_UNUSED-instead-remove-argument-n.patch
  0002-amidi-use-ATTRIBUTE_UNUSED-instead-remove-argument-n.patch
  0003-alsaloop-use-ATTRIBUTE_UNUSED-instead-remove-argumen.patch
  0004-bat-use-ATTRIBUTE_UNUSED-instead-remove-argument-nam.patch
  0005-seq-use-ATTRIBUTE_UNUSED-instead-remove-argument-nam.patch
  0006-alsaucm-use-ATTRIBUTE_UNUSED-instead-remove-argument.patch
  0007-topology-use-ATTRIBUTE_UNUSED-instead-remove-argumen.patch
* Mon May  8 2023 Takashi Iwai <tiwai@suse.com>
- Update to alsa-utils 1.2.9:
  BSD build fix, and various updates for alsactl, amidi, axfer,
  alsa-info.sh, alsaloop, alsatplg, alsaucm, aplay, abat.
  For details, see:
  https://www.alsa-project.org/wiki/Changes_v1.2.8_v1.2.9#alsa-utils
* Tue Oct 25 2022 Takashi Iwai <tiwai@suse.com>
- Update to alsa-utils 1.2.8 (jsc#PED-850):
  automake update, minor alsactl, amixer and aplay fixes.
  https://www.alsa-project.org/wiki/Changes_v1.2.7.2_v1.2.8
- Add keyring
* Wed Jun  1 2022 Takashi Iwai <tiwai@suse.com>
- Update to alsa-utils 1.2.7:
  Enhancement and fixes of alsactl, speaker-test cleanup,
  alsatplg enhancements, arecord ghost data fix, etc.
  For details see:
  https://www.alsa-project.org/wiki/Changes_v1.2.6.3_v1.2.7#alsa-utils
- Drop obsoleted patches:
  0001-alsamixer-Fix-regression-in-color-setup.patch
  0002-alsamixer-Revert-has_mouse-check.patch
* Fri Jan 28 2022 tiwai@suse.de
- Fix the broken mouse support on alsamixer:
  0002-alsamixer-Revert-has_mouse-check.patch
* Fri Jan 21 2022 tiwai@suse.de
- Fix alsamixer color config regression:
  0001-alsamixer-Fix-regression-in-color-setup.patch
* Mon Dec  6 2021 tiwai@suse.de
- Update to alsa-utils 1.2.6:
  various updates / fixes for alsactl, amidi, alsaloop, alsamixer,
  alsatplg, amixer, aplay and aseqnet.  Details are found in
    https://alsa-project.org/wiki/Changes_v1.2.5.1_v1.2.6#alsa-utils
- Update the download URL
- Add *.sig file for the tarball
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Wed Jul 28 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Modified:
  * sound-extra.service
* Mon Jun 14 2021 tiwai@suse.de
- Update to alsa-utils 1.2.5:
  a major version up, including previous patches
  https://www.alsa-project.org/wiki/Changes_v1.2.4_v1.2.5
- Update to alsa-utils 1.2.5.1:
  a small bugfix release
  https://www.alsa-project.org/wiki/Changes_v1.2.5_v1.2.5.1
- Drop the obsoleted patches:
  0001-aplay-try-to-use-16-bit-format-to-increase-capture-q.patch
  0002-alsamixer-Fix-the-mixer-views-description-in-man-pag.patch
  0003-Add-Slovak-translation.patch
  0004-Add-Basque-translation.patch
  0006-aplay-cosmetic-code-fix-in-xrun.patch
  0007-aplay-fix-the-CPU-busy-loop-in-the-pause-handler.patch
  0008-alsa-info-Add-lsusb-and-stream-outputs.patch
  0010-alsactl-Fix-double-decrease-of-lock-timeout.patch
  0011-alsactl-Fix-race-at-creating-a-lock-file.patch
  0012-alsactl-Remove-asound.state-file-check-from-alsa-res.patch
  0013-aplay-add-test-code-for-snd_pcm_status-to-test-posit.patch
  0014-ucm-fix-typo-in-docs.patch
  0015-aplay-add-avail-delay-checks-to-test-position.patch
  0016-alsactl-daemon-read_pid_file-fix-the-returned-code-o.patch
  0017-alsactl-init-set_ctl_value-fix-bytes-parsing.patch
  0018-alsactl-init-parse-fix-possible-double-free.patch
  0019-alsaloop-fix-possible-memory-leak-in-create_loopback.patch
  0020-alsaloop-get_queued_playback_samples-simplify-code.patch
  0021-topology-fix-possible-double-free-in-load.patch
  0022-alsamixer-remove-dead-fcn-widget_handle_key-in-widge.patch
  0023-alsamixer-remove-unused-variable-y-in-display_scroll.patch
  0024-alsamixer-fix-shift-in-parse_words.patch
  0025-aplay-fix-the-test-position-test-for-playback-avail-.patch
* Mon Apr 26 2021 tiwai@suse.de
- Suppress automatic update of alsa-info.sh (bsc#1185280):
  alsa-info-no-update-for-distro-script.patch
* Thu Mar 18 2021 tiwai@suse.de
- Fix superfluous asound.state migration (bsc#1183672)
* Thu Jan 21 2021 tiwai@suse.de
- Backport upstream fixes:
  various fixes in aplay, alsamixer, alsactl and alsaloop, updated
  translations, etc:
  0001-aplay-try-to-use-16-bit-format-to-increase-capture-q.patch
  0002-alsamixer-Fix-the-mixer-views-description-in-man-pag.patch
  0003-Add-Slovak-translation.patch
  0004-Add-Basque-translation.patch
  0006-aplay-cosmetic-code-fix-in-xrun.patch
  0007-aplay-fix-the-CPU-busy-loop-in-the-pause-handler.patch
  0008-alsa-info-Add-lsusb-and-stream-outputs.patch
  0013-aplay-add-test-code-for-snd_pcm_status-to-test-posit.patch
  0014-ucm-fix-typo-in-docs.patch
  0015-aplay-add-avail-delay-checks-to-test-position.patch
  0016-alsactl-daemon-read_pid_file-fix-the-returned-code-o.patch
  0017-alsactl-init-set_ctl_value-fix-bytes-parsing.patch
  0018-alsactl-init-parse-fix-possible-double-free.patch
  0019-alsaloop-fix-possible-memory-leak-in-create_loopback.patch
  0020-alsaloop-get_queued_playback_samples-simplify-code.patch
  0021-topology-fix-possible-double-free-in-load.patch
  0022-alsamixer-remove-dead-fcn-widget_handle_key-in-widge.patch
  0023-alsamixer-remove-unused-variable-y-in-display_scroll.patch
  0024-alsamixer-fix-shift-in-parse_words.patch
  0025-aplay-fix-the-test-position-test-for-playback-avail-.patch
* Fri Dec 11 2020 tiwai@suse.de
- Fix alsactl restore behavior during locking (boo#1179904):
  0010-alsactl-Fix-double-decrease-of-lock-timeout.patch
  0011-alsactl-Fix-race-at-creating-a-lock-file.patch
- Remove unnecessary condition for alsa-restore.service
  0012-alsactl-Remove-asound.state-file-check-from-alsa-res.patch
- Fix dependency in sound-extra.service
* Wed Oct 21 2020 tiwai@suse.de
- Update to alsa-utils 1.2.3:
  alsactl extension for disabling UCM, alsa-info.sh enhancements,
  various fixes and documentation updates.
  See details in
    https://alsa-project.org/wiki/Changes_v1.2.3.2_v1.2.4
* Sun Oct 18 2020 tiwai@suse.de
- Use /run/lock for alsactl lock directory (bsc#1177826)
- Migrate the old asound.state file if the new path isn't present
  yet (bsc#1177826)
* Mon Oct  5 2020 tiwai@suse.de
- Conditionally add buildreq alsa-topology-devel to fix build
  errors
* Tue Sep 29 2020 tiwai@suse.de
- Fix the directory to save asound.state again to /var/lib/alsa,
  which was mistakenly changed to /etc
* Tue Jun  9 2020 tiwai@suse.de
- Update to alsa-utils 1.2.3:
  including previous fixes, see the detailed changes at:
  https://www.alsa-project.org/wiki/Detailed_changes_v1.2.2_v1.2.3
- Dropped obsoleted patches:
  0001-alsaloop-reduce-cumulative-error-caused-by-non-atomi.patch
  0002-alsactl-don-t-exit-on-EINTR-from-epoll_wait.patch
  0003-alsactl-avoid-needless-wakeups-in-monitor-loop.patch
  0004-alsactl-fix-error-handling-for-sched_setscheduler-ca.patch
  0005-alsa-info.sh-add-ALT-to-DISTRO-list.patch
  0006-alsa-info-initial-rpm-deb-package-info.patch
  0007-alsa-info.sh-increase-version-to-0.4.65.patch
* Wed May  6 2020 tiwai@suse.de
- Backport upstream fixes: some improvements in alsa-info.sh:
  0005-alsa-info.sh-add-ALT-to-DISTRO-list.patch
  0006-alsa-info-initial-rpm-deb-package-info.patch
  0007-alsa-info.sh-increase-version-to-0.4.65.patch
* Mon Apr 20 2020 tiwai@suse.de
- Backport upstream fixes for alsactl:
  0002-alsactl-don-t-exit-on-EINTR-from-epoll_wait.patch
  0003-alsactl-avoid-needless-wakeups-in-monitor-loop.patch
  0004-alsactl-fix-error-handling-for-sched_setscheduler-ca.patch
* Fri Mar 13 2020 tiwai@suse.de
- Update to alsa-utils 1.2.2; including previous fixes
- Backport upstream fix: alsaloop improvement;
  0001-alsaloop-reduce-cumulative-error-caused-by-non-atomi.patch
- Drop obsoleted patches:
  0001-treewide-sys-poll-to-poll.patch
  0002-treewide-Fix-wrong-formats-on-32-bit.patch
  0003-treewide-Fix-printf-formats.patch
  0004-aplay-Adjust-buffer-sizes-to-fix-snprintf-warnings.patch
  0005-aplay-Limit-VUMeter-progress-bar-to-100-for-negative.patch
  0006-alsactl-sysfs-add-sys-kernel-uevent_seqnum-check-to-.patch
  0007-alsaucm-use-the-first-sound-card-use-case-name-hw-CA.patch
  0008-alsaucm-add-text-dump-command.patch
  0009-alsaucm-add-json-dump-command.patch
  0010-alsaucm-dump-fix-the-prefixed.patch
  0011-alsactl-fix-sched-idle-set-it-really-to-SCHED_IDLE.patch
  0012-configure-Fix-linking-of-alsatplg-with-the-older-lib.patch
  0013-alsatplg-add-n-normalize-option.patch
  0014-alsatplg-add-s-sort-and-fix-memory-leaks.patch
  0015-alsatplg-fix-another-small-leak-in-normalize_config.patch
  0016-alsa-info.sh-Consolidate-PCI-device-output.patch
  0017-alsa-info.sh-Read-from-proc-modules-and-sort-the-res.patch
  0018-alsa-info.sh-Simplify-iteration-over-cards-when-call.patch
  0019-alsa-info.sh-Use-existing-function-to-print-ALSA-con.patch
  0020-alsa-info.sh-Exit-script-after-writing-information-t.patch
  0021-alsa-info.sh-Replace-gauge-with-infobox-for-upload-d.patch
  0022-alsa-info.sh-Remove-progress-spinner-during-upload-w.patch
  0023-alsa-info.sh-Condense-nested-commands-for-file-uploa.patch
  0024-alsa-info.sh-Condense-nested-commands-for-formatting.patch
  0025-alsa-info.sh-Perform-test-for-wget-earlier.patch
  0026-alsa-info.sh-Warn-after-actual-upload-failure-do-not.patch
  0027-alsatplg-rewrite-to-use-the-new-libatopology-functio.patch
  0028-alsatplg-add-V-version-option.patch
  0029-alsatplg-add-decode-command.patch
  0030-alsatplg-add-documentation-for-z-dapm-nosort-h.patch
  0031-configure-fix-new-libatopology-check.patch
  0032-Use-__func__-instead-of-__FUNCTION__.patch
  0033-Avoid-pointer-arithmetic-on-void.patch
  0034-Use-lli-for-long-long-in-printf.patch
  0035-Avoid-empty-initializer-list.patch
* Wed Feb 12 2020 tiwai@suse.de
- Backport upstream fixes:
  alsatplg fixes, misc cleanups:
  0027-alsatplg-rewrite-to-use-the-new-libatopology-functio.patch
  0028-alsatplg-add-V-version-option.patch
  0029-alsatplg-add-decode-command.patch
  0030-alsatplg-add-documentation-for-z-dapm-nosort-h.patch
  0031-configure-fix-new-libatopology-check.patch
  0032-Use-__func__-instead-of-__FUNCTION__.patch
  0033-Avoid-pointer-arithmetic-on-void.patch
  0034-Use-lli-for-long-long-in-printf.patch
  0035-Avoid-empty-initializer-list.patch
- Fix build on SLE12-* target
* Tue Jan 21 2020 tiwai@suse.de
- Backport upstream patches:
  A few portability fixes, alsaucm fixes and extensions, alsatplg
  minor fixes, alsa-info.sh extensions:
  0001-treewide-sys-poll-to-poll.patch
  0002-treewide-Fix-wrong-formats-on-32-bit.patch
  0003-treewide-Fix-printf-formats.patch
  0004-aplay-Adjust-buffer-sizes-to-fix-snprintf-warnings.patch
  0005-aplay-Limit-VUMeter-progress-bar-to-100-for-negative.patch
  0006-alsactl-sysfs-add-sys-kernel-uevent_seqnum-check-to-.patch
  0007-alsaucm-use-the-first-sound-card-use-case-name-hw-CA.patch
  0008-alsaucm-add-text-dump-command.patch
  0009-alsaucm-add-json-dump-command.patch
  0010-alsaucm-dump-fix-the-prefixed.patch
  0011-alsactl-fix-sched-idle-set-it-really-to-SCHED_IDLE.patch
  0012-configure-Fix-linking-of-alsatplg-with-the-older-lib.patch
  0013-alsatplg-add-n-normalize-option.patch
  0014-alsatplg-add-s-sort-and-fix-memory-leaks.patch
  0015-alsatplg-fix-another-small-leak-in-normalize_config.patch
  0016-alsa-info.sh-Consolidate-PCI-device-output.patch
  0017-alsa-info.sh-Read-from-proc-modules-and-sort-the-res.patch
  0018-alsa-info.sh-Simplify-iteration-over-cards-when-call.patch
  0019-alsa-info.sh-Use-existing-function-to-print-ALSA-con.patch
  0020-alsa-info.sh-Exit-script-after-writing-information-t.patch
  0021-alsa-info.sh-Replace-gauge-with-infobox-for-upload-d.patch
  0022-alsa-info.sh-Remove-progress-spinner-during-upload-w.patch
  0023-alsa-info.sh-Condense-nested-commands-for-file-uploa.patch
  0024-alsa-info.sh-Condense-nested-commands-for-formatting.patch
  0025-alsa-info.sh-Perform-test-for-wget-earlier.patch
  0026-alsa-info.sh-Warn-after-actual-upload-failure-do-not.patch
* Fri Dec 20 2019 tiwai@suse.de
- Remove empty man8 dirs (used for removed alsaconf.8)
- Drop obsolete TODO and Changelog files, also irrelevant INSTALL.
- Provide alsaucm and alsatplg man pages by formatting via rst2man;
  a new dependency on python3-docutils is added
* Sun Nov 24 2019 Neal Gompa <ngompa13@gmail.com>
- Replace incorrect usage of %%_libexecdir with %%_prefix/lib
* Fri Nov 15 2019 tiwai@suse.de
- Update to alsa-utils 1.2.1:
  * axfer: handle -ETIMEDOUT before non-block I/O operation
  * axfer: code refactoring for a helper function to wait for avail buffer space
  * axfer: handle -ETIMEDOUT before handle mmap I/O operation
  * axfer: return ETIMEDOUT when no event occurs after waiter expiration
  * axfer: fix to return error code when a call of select(2) fails
  * axfer: return the number of file descriptors for I/O events from select(2) waiter
  * axfer: test: fix invalid comparison of 64 bit storage in ILP32 data type
  * axfer: mapper: fix parameter check for demuxer
  * axfer: remove unused variable warnings
  * alsamixer: Remove exp10 usage
  * alsaucm, topology: LDADD cleanups and add support for libatopology
  * alsaucm: fix the implicit card open
  * alsaucm, topology: LDADD cleanups and add support for libatopology
  * alsaucm: do the implicit ucm open only when the command requires it
  * alsaucm: call snd_config_update_free_global() to make valgrind more happy
  * amixer: do not double LF for container type
  * aplay: fix memory leak when setup_chmap() fail
* Tue Jun 11 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Tue May 28 2019 tiwai@suse.de
- Add systemd service to load OSS and sequencer modules
  (bsc#1136562)
* Fri May 10 2019 tiwai@suse.de
- Update to alsa-utils 1.1.9:
  alasctl, axfer, alsaloop, alsamixer and amixer fixes, see
    https://www.alsa-project.org/wiki/Changes_v1.1.8_v1.1.9
  for details
* Tue Jan 22 2019 tiwai@suse.de
- Remove the ugly conditionals to build for (too) old distros
- Drop alsaconf script that rather brings the inconsistent setup
  on modern systems
- Move alsabat-test.sh into alsabat package, too
- Run spec-cleaner
* Tue Jan  8 2019 tiwai@suse.de
- Update to alsa-utils 1.1.8:
  * Core:
    Makefile.am: add README.md to EXTRA_DIST
    axfer: add support for libffado transmission backend
    axfer: add unit test for container interface
    axfer: add an entry point for this command
    initial version of .travis.yml
    rename and update README.md
  * Audio Transfer utility:
    axfer: add an explanation about advantages/issues of Timer-based scheduling model
    axfer: add an explanation about Timer-based scheduling model
    axfer: add an explanation about IRQ-based scheduling model
    axfer: add text for compatibility loss of sw parameter in libasound backend
    axfer: fulfill manual section for libasound backend
    axfer: print help for libasound backend
    axfer: fulfill manual section for libffado backend
    axfer: print help for libffado backend
    axfer: correct description about signal handling
    axfer: fix typo in axfer(1) manual
    axfer: fix no return statement in print_help() function
    axfer: enable each backend to print own help
    axfer: print help text of transfer subcommand just for common options
    axfer: print help text of list subcommand
    axfer: print help text of command entry
    axfer: add a section about design of transfer subcommand
    axfer: add a section to describe compatibility to aplay(1)
    axfer: add a manual for transfer subcommand
    axfer: add a manual for list subcommand
    axfer: add a manual for entry point
    axfer: check whether a terminal is referred for stdio
    axfer: truncate parsed arguments before operating subcommand
    axfer: use transfer subcommand as a default for compatibility mode to aplay(1)
    axfer: use second argument in command line for transmission direction
    axfer: apply refactoring in list subcommand for new command system
    axfer: apply refactoring to list subcommand for backward compatibility to aplay(1)
    axfer: add support for libffado transmission backend
    axfer: obsolete some unimplemented options
    axfer: add support for timer-based scheduling model with MMAP operation
    axfer: add an implementation of waiter for epoll(7)
    axfer: add an implementation of waiter for select(2)
    axfer: add an implementation of waiter for poll(2)
    axfer: add an option for waiter type
    axfer: add a common interface of waiter for I/O event notification
    axfer: add options for plugins in alsa-lib
    axfer: add options for software parameters of PCM substream
    axfer: add options for buffer arrangement
    axfer: add an option to suppress event waiting
    axfer: add support for MMAP PCM operation
    axfer: add support for non-blocking operation
    axfer: add an option to finish transmission at XRUN
    axfer: add options related to duration and obsolete '--max-file-size' option
    axfer: add an option to dump available hardware parameters
    axfer: add informative output and an option to suppress it
    axfer: add a sub-command to transfer data frames
    axfer: add support for blocking data transmission operation of alsa-lib PCM API
    axfer: add support to transfer data frames by alsa-lib PCM APIs
    axfer: add a parser for command-line options
    axfer: add a common interface to transfer data frames
    axfer: add a unit test for mapper interface
    axfer: add support for a mapper for multiple target
    axfer: add support for a mapper for single target
    axfer: add a common interface to align data frames on different layout
    axfer: add unit test for container interface
    axfer: add support for a container of raw data
    axfer: add support for a container of Creative Tech. voice format
    axfer: add support for a container of Sparc AU format
    axfer: add support for a container of Microsoft/IBM RIFF/Wave format
    axfer: add a common interface to handle a file with audio-specific data format
    axfer: add a sub-command to print list of PCMs/devices
    axfer: add an entry point for this command
  * alsaloop:
    alsaloop: more avail_min cleanups
  * alsatplg (topology):
    topology/topology.c: drop unneeded <dlfcn.h> include
  * aplay/arecord:
    aplay: improve available conditions for '--samples' and '--duration' options
    aplay: add a paragraph for '--samples' ('-s') option to aplay manual
    aplay: delete paragraph for obsoleted '--sleep-min' ('-s') option from aplay manual
* Mon Oct 22 2018 Christian Boltz <suse-beta@cboltz.de>
- remove "Obsoletes: bat <= 0.1.0" - it triggers uninstall of the unrelated
  "bat" (cat clone) package
* Wed Oct 17 2018 tiwai@suse.de
- Updated to alsa-utils 1.1.7:
  * aplay: Fix invalid file size check for non-regular files
  * speaker-test: Support S24_3LE sample format
  * speaker-test: Allow sampling rates up to 768000
  * alsabat: Allow custom sample format for round trip latency test
  * alsaucm: add alsa-ucm udev rules for PAZ00 (Toshiba AC100/Dynabook AZ)
  * alsatplg: add man file
  * alsactl: improved disconnection handling
  * compile warning fixes
  * aplay: add missing block brackets
- Prepare a patch to allow build with old automake for old distros
  (not applied yet, though):
  alsa-utils-configure-version-revert.patch
* Wed Apr  4 2018 tiwai@suse.de
- Avoid %%license tag for old distros to fix builds
* Wed Apr  4 2018 tiwai@suse.de
- Updated to alsa-utils 1.1.6:
  * Change FSF address (Franklin Street)
  * aplay: Adjust sample rate limits to support newer hardware
  * alsactl: Only start restore service when asoundrc file exists
  * alsaloop: fix a typo in the comparison
  * speaker-test: Refactor the tone-generator codes
  * aplay: Fix wav file not being split on 32 bit platforms
  * bat: alsa.c - move the thread cleanup pop before goto exit3
- Remove obsoleted patches:
  0001-aplay-Adjust-sample-rate-limits-to-support-newer-har.patch
  0002-alsactl-Only-start-restore-service-when-asoundrc-fil.patch
- Use %%license file tag
* Mon Dec 18 2017 tiwai@suse.de
- Get rid of superfluous patch for ancient distros:
  alsa-utils-gettext-version-removal.diff
- Remove superfluous file override, which is already included in
  the 1.1.5 tarball:
  alsaucm.rst
- Backport upstream fixes:
  0001-aplay-Adjust-sample-rate-limits-to-support-newer-har.patch
  0002-alsactl-Only-start-restore-service-when-asoundrc-fil.patch
- Cleanup specfile to rip off the too old kludges
* Tue Nov 14 2017 tiwai@suse.de
- Update to alsa-utils 1.1.5:
  * alsactl: Move systemd unit start-up from basic.target to
    sound.target
  * alsatplg: fix topology compiler long option parsing
  * topology: delete output file if parsing fails.
  * aplay: Fix playback for small raw files
  * aplay: Refactor playback code
  * aplay: Add samples argument for playing/recording a given
    number of samples
  * aplay: interrupt streaming via signal in voc_pcm_write
  * aplay: Fix --max-file-time option 32 bits overflow
  * alsabat: fix one uninitialized warning issue
- Fix filelist for the 1.1.5 update
* Mon Nov  6 2017 jmatejek@suse.com
- drop unused requirement for python-docutils
* Tue May 16 2017 tiwai@suse.de
- Update to alsa-utils 1.1.4:
  * alsactl: Remove standard output definition in systemd unit
  * alsa-info: provide more DMI information
  * alsa-info: add ACPI device status
  * amidi: optarg might be NULL, fix 't' argument parsing
  * aplay: Introduce and use xwrite helper
* Wed Dec 28 2016 tiwai@suse.de
- Really bump the version number to 1.1.3 (sorry, forgot to change
  in Version tag).
* Wed Dec 28 2016 tiwai@suse.de
- Update to alsa-utils 1.1.3:
  * a couple of amidi fixes
  * a few alsabat extensions
  * alsaloop cpu hog fix,
  * a fix for suspend/resume with aplay
  * fix chmap selection in speaker-test WAV mode
  * alsaucm man pages,
  * fix potential NULL dereferences in alsactl daemon mode
- Add python-docutils to build dependency (for rst2man)
- Fix missing alsaucm man page file in the 1.1.3 tarball
* Wed Aug  3 2016 tiwai@suse.de
- Update to alsa-utils 1.1.2:
  * aplay: fix lurking capture file overwrite bug
  * alsabat: a few bug fixes, add noise detection, etc
* Thu Mar 31 2016 tiwai@suse.de
- Update to alsa-utils 1.1.1:
  including previous fixes, more enhancements / fixes of alsabat,
  fix in aplay for parsing parameter values
- Delete obsoleted patches:
  0001-bat-Avoid-local-signal.h-file.patch
  0002-bat-Don-t-pass-incompatible-function-pointers-to-pth.patch
  0003-alsa-info.sh-add-man-page.patch
  0004-amixer-skip-showing-asoc-tlv-byte-controls.patch
  0005-alsabat-rename-to-avoid-naming-conflict.patch
* Wed Feb  3 2016 tiwai@suse.de
- Backport upstream fixes: add alsa-info manpage, fix TLV output of
  amixer for ASoC ext ctls, and rename from bat to alsabat
  0003-alsa-info.sh-add-man-page.patch
  0004-amixer-skip-showing-asoc-tlv-byte-controls.patch
  0005-alsabat-rename-to-avoid-naming-conflict.patch
- Rename subpackage from bat to alsabat due to the name conflicts
  with other projects
* Mon Nov  9 2015 tiwai@suse.de
- Update to alsa-utils 1.1.0:
  including all previous fixes, update of topology tool, addition
  of BAT (Basic Audio Tool)
- Split bat subpackage containing BAT
- Fix build of bat with old gcc & glibc on SLE11
  0001-bat-Avoid-local-signal.h-file.patch
  0002-bat-Don-t-pass-incompatible-function-pointers-to-pth.patch
- Dropped patches:
  0001-amixer-Don-t-set-only-the-first-item-in-sset_enum.patch
  0002-amixer-expand-local-storage-for-item-name-according-.patch
  0003-alsa-info-Don-t-try-update-when-wget-isn-t-available.patch
  0004-aplay-Fix-type-for-signal-flag.patch
  0005-aplay-Fix-uninterruptible-aplay.patch
  0006-alsactl-terminate-readlink-result-string.patch
  0007-speaker-test-Add-option-to-specify-signal-scale.patch
  0008-topology-Add-command-line-topology-tool-to-build-top.patch
  0009-alsactl-Add-path-condition-to-alsa-store-and-alsa-re.patch
  0010-speaker-test-fix-option-ordering.patch
  0011-arecord-Remove-only-regular-files.patch
  0012-aplay-fix-VU-meter-for-S24_LE-etc-formats.patch
  0013-alsactl-Manage-both-save-and-restore-in-a-single-uni.patch
* Tue Sep 29 2015 tiwai@suse.de
- Backport upstream fixes: particularly fixing the inconsistent
  mixer state after service reload (bnc#929619):
  0010-speaker-test-fix-option-ordering.patch
  0011-arecord-Remove-only-regular-files.patch
  0012-aplay-fix-VU-meter-for-S24_LE-etc-formats.patch
  0013-alsactl-Manage-both-save-and-restore-in-a-single-uni.patch
* Mon Aug 10 2015 tiwai@suse.de
- Suppress alsactl invocation on systems without sound cards
  (bsc#940950):
  0009-alsactl-Add-path-condition-to-alsa-store-and-alsa-re.patch
* Tue Aug  4 2015 tiwai@suse.de
- Upstream patch to add -S option to speaker-test
  0007-speaker-test-Add-option-to-specify-signal-scale.patch
- Upstream patch to add alsatplg parser program
  0008-topology-Add-command-line-topology-tool-to-build-top.patch
- Reenable autoreconf call to regenerate after patching
* Fri Jul 31 2015 dimstar@opensuse.org
- Change libudev-devel BuildRequires to pkgconfig(udev): makes us
  less prone to packaging changes, and in the end udev.pc is
  exactly what we need to define _udevdir.
* Mon Jul 13 2015 tiwai@suse.de
- Backport upstream fixes for aplay signal handling and alsactl
  possible buffer overflow of readlink():
  0004-aplay-Fix-type-for-signal-flag.patch
  0005-aplay-Fix-uninterruptible-aplay.patch
  0006-alsactl-terminate-readlink-result-string.patch
* Mon Apr 27 2015 tiwai@suse.de
- Backport upstream fixes, including the fix for alsa-info
  (boo#928394):
  0001-amixer-Don-t-set-only-the-first-item-in-sset_enum.patch
  0002-amixer-expand-local-storage-for-item-name-according-.patch
  0003-alsa-info-Don-t-try-update-when-wget-isn-t-available.patch
* Thu Feb 26 2015 tiwai@suse.de
- Update to alsa-utils 1.0.29:
  just a version bump including previous fixes
- Drop obsoleted patches:
  0001-alsactl-save-state-do-not-call-rename-for-stdio.patch
  0002-alsamixer-include-missing-mixer_controls.h.patch
  0003-Add-alsa-info.sh-to-alsa-utils-repo.patch
  0004-Add-missing-alsa-info-entry-to-the-root-Makefile.am.patch
  0005-alsa-info-Make-sure-all-full-script-is-run-even-with.patch
  0006-alsa-info-Refactor-withall-logic.patch
  0007-speaker-test-Add-missing-draining-at-the-end.patch
  0008-alsactl-Fix-the-file-locking-routines-for-the-state-.patch
  0009-alsactl-aded-missing-monitor-prototype.patch
  0010-speaker-text-fix-simple-signess-assignment-warning.patch
  0011-monitor-fix-clang-warning-Declared-variable-length-a.patch
  0012-alsactl-coverity-missing_va_end-va_end-was-not-calle.patch
  0013-Revert-aplay-fix-pcm_read-return-value.patch
  0014-amixer-Make-dB-case-insensitive-in-set-commands.patch
  0015-amixer-Parse-the-value-more-strictly.patch
  0016-alsactl-add-missing-state_unlock-call.patch
  0017-alsactl-init-Change-the-basic-rules-description.patch
  0018-alsactl-init-Add-Line-Out-to-list-of-outputs-to-init.patch
  0019-configure-allow-contitional-compilation-of-alsaucm.patch
* Mon Jan 26 2015 tiwai@suse.de
- Backport upstream fixes: fix missing unlock for the error path
  in alsactl, more alsactl init entries, alsaucm build fix
  0016-alsactl-add-missing-state_unlock-call.patch
  0017-alsactl-init-Change-the-basic-rules-description.patch
  0018-alsactl-init-Add-Line-Out-to-list-of-outputs-to-init.patch
  0019-configure-allow-contitional-compilation-of-alsaucm.patch
* Fri Dec  5 2014 tiwai@suse.de
- Backport upstream fixes: rubustify dB value handling in amixer
  0014-amixer-Make-dB-case-insensitive-in-set-commands.patch
  0015-amixer-Parse-the-value-more-strictly.patch
* Fri Oct 17 2014 tiwai@suse.de
- Backport upstream fixes: a few speaker-test fixes, minor alsactl
  fixes and a revert of a wrong fix for aplay.
  0007-speaker-test-Add-missing-draining-at-the-end.patch
  0008-alsactl-Fix-the-file-locking-routines-for-the-state-.patch
  0009-alsactl-aded-missing-monitor-prototype.patch
  0010-speaker-text-fix-simple-signess-assignment-warning.patch
  0011-monitor-fix-clang-warning-Declared-variable-length-a.patch
  0012-alsactl-coverity-missing_va_end-va_end-was-not-calle.patch
  0013-Revert-aplay-fix-pcm_read-return-value.patch
* Tue Aug 26 2014 tiwai@suse.de
- alsa-info.sh updates to 0.4.64: run withall also when --output
  is given
  0005-alsa-info-Make-sure-all-full-script-is-run-even-with.patch
  0006-alsa-info-Refactor-withall-logic.patch
* Tue Aug 12 2014 tiwai@suse.de
- Move alsa-info.sh to alsa-utils:
  0003-Add-alsa-info.sh-to-alsa-utils-repo.patch
  0004-Add-missing-alsa-info-entry-to-the-root-Makefile.am.patch
* Tue Jul  1 2014 tiwai@suse.de
- Remove obsoleted *.po files
- Backport upstream fixes:
  0001-alsactl-save-state-do-not-call-rename-for-stdio.patch
  0002-alsamixer-include-missing-mixer_controls.h.patch
* Wed Jun 18 2014 tiwai@suse.de
- Updated to alsa-utils 1.0.28:
  All pervious fix patches are obsoleted:
  0001-alsactl-alsa-state.service-fix-typo-rkill-kill.patch
  0002-alsaloop-fix-wrong-alias-for-signal.h.patch
  0003-aplay-fix-two-off-by-one-errors.patch
  0004-alsaloop-add-z-syslog-option-to-use-syslog-for-error.patch
  0005-amixer-actually-print-all-TLVs-in-a-container-TLV.patch
  0006-amixer-fix-indentation-when-printing-container-TLV-c.patch
  0007-alsaloop-pcmjob.c-use-portable-way-to-initialize-rec.patch
  0008-speaker-test-Fix-chmapped-channel-selection-without-.patch
  0009-speaker-test-Always-show-chmap-channel-names-if-avai.patch
  0010-speaker-test-Show-out-of-chmap-channels-as-Unknown.patch
  0011-alsaconf-support-newer-m-i-t-and-kmod.patch
  0012-alsaconf-update-gentoo-to-use-modprobe.d-method-as-e.patch
  0013-configure-detect-udevdir-via-pkg-config-fallback-to-.patch
  0014-alsactl-Add-monitor-command.patch
  0015-alsactl-Fix-REMOVE-event-handling-in-monitor-command.patch
  0016-alsactl-monitor-all-cards-as-default.patch
  0017-alsactl-Fix-the-va_list-initialization-in-cerror_-an.patch
  0018-aplay-fix-pcm_read-return-value.patch
  0019-alsa-restore.rules-refer-to-correct-attr.patch
  0020-aplay-fix-timespec-to-msec-conversion.patch
  0021-speaker-test-add-force-frequency-option-to-allow-hz-.patch
  0022-speaker-test-update-man-page-for-new-X-arg-also-cons.patch
* Tue Mar 11 2014 tiwai@suse.de
- Upstream backports: Add --force-frequency option to speaker-test
  0021-speaker-test-add-force-frequency-option-to-allow-hz-.patch
  0022-speaker-test-update-man-page-for-new-X-arg-also-cons.patch
- Temporarily add the raw *.po files for properly patching
- Run spec-cleaner
* Fri Jan 31 2014 tiwai@suse.de
- Backport minor fix patches for alsactl and aplay from upstream:
  0017-alsactl-Fix-the-va_list-initialization-in-cerror_-an.patch
  0018-aplay-fix-pcm_read-return-value.patch
  0019-alsa-restore.rules-refer-to-correct-attr.patch
  0020-aplay-fix-timespec-to-msec-conversion.patch
* Wed Nov 27 2013 tiwai@suse.de
- Backport upstream fixes: a few fixes for chmap support, alsaconf
  updates, a new monitor command for alsactl, etc:
  0006-amixer-fix-indentation-when-printing-container-TLV-c.patch
  0007-alsaloop-pcmjob.c-use-portable-way-to-initialize-rec.patch
  0008-speaker-test-Fix-chmapped-channel-selection-without-.patch
  0009-speaker-test-Always-show-chmap-channel-names-if-avai.patch
  0010-speaker-test-Show-out-of-chmap-channels-as-Unknown.patch
  0011-alsaconf-support-newer-m-i-t-and-kmod.patch
  0012-alsaconf-update-gentoo-to-use-modprobe.d-method-as-e.patch
  0013-configure-detect-udevdir-via-pkg-config-fallback-to-.patch
  0014-alsactl-Add-monitor-command.patch
  0015-alsactl-Fix-REMOVE-event-handling-in-monitor-command.patch
  0016-alsactl-monitor-all-cards-as-default.patch
* Tue Oct  1 2013 tiwai@suse.de
- Upstream fixes: addition of -z option to alsaloop, and a fix for
  amixer TLV parser
  0004-alsaloop-add-z-syslog-option-to-use-syslog-for-error.patch
  0005-amixer-actually-print-all-TLVs-in-a-container-TLV.patch
* Mon Sep  9 2013 tiwai@suse.de
- Upstream fix:
  0003-aplay-fix-two-off-by-one-errors.patch
* Fri Sep  6 2013 tiwai@suse.de
- Upstream fix:
  0002-alsaloop-fix-wrong-alias-for-signal.h.patch
* Fri Jul 19 2013 tiwai@suse.de
- remove superfluous ca0106 file (now included in 1.0.27.2)
* Fri Jul 19 2013 tiwai@suse.de
- updated to version 1.0.27.2
  including all previous fixes
- fix a typo in alsa-state.service:
  0001-alsactl-alsa-state.service-fix-typo-rkill-kill.patch
* Mon Jun 17 2013 tiwai@suse.de
- Backport upstream fixes wrt chmap handling:
  0006-amixer-Print-TLV-of-channel-map-controls.patch
  0007-speaker-test-Fix-wrong-wave-file-played-back-in-chma.patch
* Wed May 29 2013 tiwai@suse.de
- Backport upstream fixes wrt amixer:
  0004-amixer-Fix-the-hctl-elem-search-bug.patch
  0005-amixer-fix-print_dB-for-0.99-.-0.01-range.patch
* Mon May 27 2013 tiwai@suse.de
- Backport upstream fixes:
  0002-alsactl-init-ca0106-file-was-omitted.patch
  0003-alsactl-return-back-the-udevrules_DATA-rule-for-90-a.patch
- Add missing ca0106 alsactl init file
- Revert the udev file drop in the previous commit
* Thu May 23 2013 tiwai@suse.de
- Bump to version 1.0.27.1, including previous fixes
- Removed requirement of libudev-devel, as the superfluous rules
  file is dropped in 1.0.27.1.
- Backport upstream fix:
  0001-Release-v1.0.27.1.patch
* Thu Apr 18 2013 tiwai@suse.de
- Upstream fix: arecord: add a missing break to the capture loop
  0003-arecord-add-a-missing-break-to-the-capture-loop.patch
* Mon Apr 15 2013 hrvoje.senjan@gmail.com
- Added patch from upstream, which fixes buffer overflow,
  0002-alsactl-Fix-the-string-size-for-the-lock-file-contents.patch
* Mon Apr 15 2013 tiwai@suse.de
- Replace the previous fix with the upstream patch
* Sat Apr 13 2013 hrvoje.senjan@gmail.com
- Added service_typo.patch, fixes alsa-restore service not starting
* Fri Apr 12 2013 tiwai@suse.de
- Update to version 1.0.27:
  including all previous fixes; all 00*-* patches dropped
  * Add support for alsactl daemon mode
  * Add snd_pcm_abort() support in aplay
* Fri Feb  1 2013 tiwai@suse.de
- Backport a few fix patches from upstream git tree:
  0012-aplay-Add-the-support-for-big-endian-WAV-format-RIFX.patch
  0013-configure-Fix-obsolete-AM_CONFIG_HEADER-macro.patch
  0014-speaker-test-increase-the-maximum-supported-rate-to-.patch
  0015-amixer-Fix-dB-value-outputs-in-amixer-contents.patch
* Sat Dec  1 2012 tiwai@suse.de
- Add libsamplerate-devel to buildrequires for alsaloop
  (bnc#792173)
* Fri Nov 30 2012 tiwai@suse.de
- Build with libsamplerate for aloop (bnc#792173)
- Add a patch to handle alsaloop properly without libsamplerate
  (bnc#792173):
  0010-alsaloop-Make-alsaloop-working-without-libsamplerate.patch
  0011-alsaloop-Fix-missing-endif.patch
* Thu Nov 29 2012 tiwai@suse.de
- Backport fixes from upstream
  0006-alsamixer-fix-handling-of-removed-controls.patch
  0007-aplay-Show-usage-if-no-parameter-is-passed.patch
  0008-amixer-fix-rounding-of-relative-changes.patch
  0009-amixer-Fix-parsing-container-TLV-entries.patch
* Mon Nov 12 2012 tiwai@suse.de
- Fix build breakage on 11.4
- Correct udev rules path (the recent udev places /usr/lib/udev)
* Sat Nov  3 2012 crrodriguez@opensuse.org
- Fix systemd units location in factory.
* Wed Oct 17 2012 tiwai@suse.de
- backport from upstream tree:
  * add support for the new chmap API
* Mon Sep 10 2012 tiwai@suse.de
- Updated to version 1.0.26; including previous fixes
* Wed Jun 20 2012 tiwai@suse.de
- Fix the installation of postinit rules
- Add (empty) preinit directory for alsactl init as a placeholder
* Fri Jun 15 2012 tiwai@suse.de
- Make beep silent as default (bnc#767270)
- Backport fixes for alsactl init
- Fix invalid .LO entry in man page
* Tue May 29 2012 tiwai@suse.de
- backport fix patches from upstream:
  * Some document fixes
  * Improve xrun_sync in alsaloop
  * Add option to dump HW parameters to aplay
  * Add the support for mapped volumes to amixer
  * Add option to tread any xrun as fatal to aplay/arecord
  * configure.in fixes
  * alsactl: Don't access other cards than specified
  * aplay prints Vu-meter to stderr now
  * fix the avail_min setup in alsaloop
* Wed Jan 25 2012 tiwai@suse.de
- updated to version 1.0.25; including all previous fixes
* Thu Dec 22 2011 crrodriguez@opensuse.org
- alsa-utils is of no use without alsa, add requires
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Nov  4 2011 tiwai@suse.de
- Fix missing initialization of Surround, etc, as well as Front
  Speaker, etc mixer elements in alsactl init
* Wed Nov  2 2011 tiwai@suse.de
- Backport upstream fix:
  - fix a crash of alsamixer with pulse plugin
* Tue Sep 20 2011 tiwai@suse.de
- Backport upstream fixes
  - Increase the max channels of aplay to 256.
  - Fix sed usage in Makefile.am
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Tue Jun 28 2011 tiwai@suse.de
- Improved speaker-test man page
- Fix DB_RANGE TLV type handling in amixer
* Fri Jun  3 2011 tiwai@suse.de
- Backport alsa-utils fixes from upstream:
  0001-alsamixer-fix-display-of-active-inactive-controls.patch
  0002-alsaloop-libsamplerate-requires-specific-formats-for.patch
  0003-alsaloop-another-try-to-force-correct-formats-for-li.patch
  0004-alsamixer-fix-build-on-uClibc.patch
  0005-alsactl-init-Mute-CD-Playback-volume-by-default.patch
  0006-Revert-alsactl-Display-help-for-names-command.patch
  0007-alsaucm-Add-list1-command-for-non-tuple-lists.patch
  0008-alsaucm-Don-t-double-free-empty-lists.patch
  0009-aplay-Add-i-option-for-interactive-mode.patch
  0010-aplay-Avoid-recursive-signal-handling.patch
  0012-alsaloop-Use-AM_CFLAGS-in-Makefile.am.patch
  0013-Updated-COPYING-with-the-recent-FSF-address.patch
  0014-alsamixer-Fix-64bit-issues.patch
  0015-aplay-Add-include-files-for-mkdir.patch
  0016-aplay-Use-standard-endian-convesions.patch
* Mon Jan 31 2011 tiwai@suse.de
- updated to version 1.0.24.2:
  * including previous fixes
  * add UCM support
* Thu Dec  9 2010 tiwai@suse.de
- Use cubic scale for alsamixer volume bars for better usability
- Misc fixes from upstream
* Tue Nov 30 2010 tiwai@suse.de
- Add the missing /var/lib/alsa to filelist
* Fri Nov 26 2010 tiwai@suse.de
- add /lib/systemd/service/alsasound.service to make systemd
  skipping old sysv script
* Fri Nov 26 2010 tiwai@suse.de
- drop explicit buildrequires on systemd
* Fri Nov 26 2010 tiwai@suse.de
- backport GIT PATCHES:
  * A few alsactl init fix patches:
    0014-alsactl-init-Handle-Capture-Source-and-Mic-Boost-in-.patch
    0015-alsactl-init-Initialize-also-Master-Front-Playback-V.patch
  * amixer control-id parse fix
    0016-amixer-fix-parsing-of-control-ID-name.patch
  * new aloop utility
    0017-Introduce-alsaloop-utility.patch
    0018-alsaloop-Fix-loopbacks-pointer-initialization-and-al.patch
    0019-alsaloop-Fix-thread-handling.patch
    0020-alsaloop-fix-a-option-and-slave-mode-processing.patch
    0021-alsaloop-fix-resample-argument-parsing.patch
    0022-alsaloop-added-resampling-for-unsupported-soundcard-.patch
    0023-alsaloop-Add-OSS-mixer-redirection-support.patch
    0024-alsaloop-Fix-command-line-parsing-and-pollfd-initial.patch
    0025-alsaloop-Fixes-and-added-workaround-option.patch
    0026-alsaloop-add-pctl-and-cctl-options.patch
    0027-alsaloop-add-pctl-and-cctl-options-to-man-page.patch
    0028-alsaloop-added-xrun-profiling-support-U-xrun-added-S.patch
    0029-alsaloop-add-U-xrun-to-alsaloop.1-man-page.patch
    0030-alsaloop-fixes-added-W-wake-option.patch
    0031-alsaloop-Fix-latency-print.patch
    0033-alsaloop-Delay-the-restart-a-bit-to-handle-snd-aloop.patch
    0034-alsaloop-rework-the-ctl-event-handling-routine.patch
  * robusitfy speaker-test
    0032-speaker-test-Don-t-retry-after-fatal-errors.patch
  * misc clean up, translation updates
    0035-alsamixer-remove-obsolete-e-mail.patch
    0036-update-German-translations.patch
  * systemd integration
    0037-alsactl-systemd-and-udev-hookup.patch
    0038-alsactl-Move-asound.state-location-to-var-lib-alsa.patch
    0039-configure.in-Fix-variable-name.patch
- Use systemd for openSUSE 11.4
- Put udev rules into this package instead of alsa.rpm
* Thu Sep  2 2010 tiwai@suse.de
- backported GIT patches:
  * 0001-alsactl-use-snd_config_imake-functions.patch
  * 0002-alsactl-move-alloca-out-of-loop.patch
  * 0003-alsactl-remove-open-coded-search.patch
  * 0004-alsactl-correctly-restore-dB-values-of-controls-with.patch
  * 0005-alsactl-change-format-of-comment-node-in-state-file.patch
  * 0006-Revert-wrong-parts-of-alsactl-use-snd_config_imake-f.patch
  * 0007-aplay-arecord-Added-hardware-pause-support-press-SPA.patch
  * 0008-aplay-fix-termio-settings-return-back-old-c_flag-val.patch
  * 0009-speaker-test-add-test-pattern-for-PCM-layer-debuggin.patch
  * 0010-aplay-arecord-term_c_lflag-variable-might-be-unitial.patch
  * 0011-alsactl-init-Use-Found-hardware-instead-Unknown-hard.patch
  * 0012-alsactl-init-use-generic-method-instead-guess-method.patch
  * 0013-alsactl-Change-handling-of-inactive-controls.patch
* Mon Apr 19 2010 tiwai@suse.de
- updated to version 1.0.23:
  * including previous fixes
  * aconnect -x: Do not update index after removal of connection.
* Mon Mar  8 2010 tiwai@suse.de
- Backport upstream fixes:
  * aplay: Dump PCM state on xrun when verbose mode is active
  * aplay - add option --process-id-file
  * aplay -- add features for audio surveilance
  * aplay -- update the man file
  * amidi: fix port listing
  * speaker-test: add fflush(stdout) to write_loop
  * amixer: fix display of unreadable control elements
  * amixer: add support for TLV dB minmax types
  * alsactl: Fix return code
  * alsamixer: fix division by zero
  * alsamixer: handle out-of-range volume values
  * alsactl: improve -d to get warnings and store exitcode to runstate file
  * alsactl: add more debug prints to state.c
  * alsactl: update debug prints in state.c
* Fri Dec 18 2009 tiwai@suse.de
- set AUTOMAKE_JOBS for parallel automake
* Fri Dec 18 2009 tiwai@suse.de
- updated to version 1.0.22:
  * including previous fixes
* Wed Sep  2 2009 tiwai@suse.de
- fix build with older distros; removed an obsolete patch
- fix alsactl init syntax errors in the default config
* Mon Aug 31 2009 tiwai@suse.de
- updated to version 1.0.21:
  just a version bump including previous fixes
* Wed Aug 12 2009 tiwai@suse.de
- fix alsactl init Speaker volume setup
* Fri Jun 19 2009 tiwai@suse.de
- tricolorize alsamixer volumes
- fix alsactl init values
* Tue Jun  2 2009 tiwai@suse.de
- fix alsamixer man page about capture elements
* Fri May 29 2009 tiwai@suse.de
- sync with the upstream:
  * alsamixer code rewrite
  * more alsactl init fixes
  * translations updates
* Wed May 20 2009 tiwai@suse.de
- speaker-test minor clean-ups
- fix alsactl init headphone volume setup
* Wed May  6 2009 tiwai@suse.de
- updated to version 1.0.20:
  * including previous patches
  * a few more fixes about alsactl init command
* Thu Apr 23 2009 tiwai@suse.de
- updated as of 2009.04.23:
  * Added vi-like key bindings to alsamixer
  * alsactl/init: Fix CTL{value} assigning - make it relevant to
    documentation
  * aplay/arecord: improve suspicious buffer detection and add
  - -test-coef parameter
  * aplay/arecord: remove debug printfs introduced by previous
    patch
  * aplay/arecord: fix underrun/overrun time calculation for
    monotonic clock
* Wed Mar 18 2009 tiwai@suse.de
- add missing -I option for alsactl
- prefer /etc/modprobe.d/50-sound.conf for new module-init-tools
* Mon Feb 16 2009 tiwai@suse.de
- alsactl: init - modify default rule to better support some HDA
  codecs
- Fix build with partially-installed alsa-lib
* Thu Jan 22 2009 tiwai@suse.de
- updated to version 1.0.19
- use ANSI-C functions instead of index()
* Wed Nov 26 2008 tiwai@suse.de
- fix division-by-zero error in speaker-test program
* Wed Oct 29 2008 tiwai@suse.de
- updated to version 1.0.18-final;
  just including all previous fixes
* Thu Oct 23 2008 tiwai@suse.de
- added --test-position in aplay/arecord for debugging
- can disable the build of alsaconf in configure
- alsactl -g option to ignore 'no soundcards' error
* Thu Sep 11 2008 tiwai@suse.de
- fix possible segfaults during parsing in alsactl
* Wed Sep 10 2008 tiwai@suse.de
- updated to 1.0.18rc3:
  * more alsactl init implementations
* Wed Aug  6 2008 tiwai@suse.de
- alsactl init implementation (still non-working status, though)
- iecset utility updates for new IEC958 status bits
* Tue Jul 15 2008 tiwai@suse.de
- updated to 1.0.17-final:
  * just a version bump
* Wed Jun 18 2008 tiwai@suse.de
- updated to 1.0.17rc2:
  * including last fixes
* Wed Apr 16 2008 tiwai@suse.de
- HG snapshot 20080416:
  * fix a cast warning in aplay
  * use ncurses*-config in configure
* Fri Mar 14 2008 tiwai@suse.de
- HG snapshot 20080314:
  * stereo VU-meter support in aplay
* Mon Mar 10 2008 tiwai@suse.de
- HG snapshot 20080309:
  * support extensible WAV format in aplay
  * flush output in aseqdump
  * fix poll timeout in seq/* utils
  * clean up configure
* Wed Feb 13 2008 tiwai@suse.de
- clean up configure script
- add support of IEEE float in aplay/arecord
* Fri Feb  8 2008 tiwai@suse.de
- updated to version 1.0.16-final:
  * just a version bump
* Tue Jan 22 2008 tiwai@suse.de
- updated to version 1.0.16-rc1:
  * just a version bump
* Wed Jan  9 2008 tiwai@suse.de
- updated to HG 2008.01.09 version:
  * alsact: skip inactive controls
  * alsamixer: add 8-channel support
  * aplay, speaker-test: remove obsolete APIs
* Fri Dec 14 2007 tiwai@suse.de
- updated to HG 2007.12.14 version:
  * merged previous patches
  * fix blocking mode around snd_pcm_drain() calls in aplay
* Fri Nov 30 2007 tiwai@suse.de
- Merge upstream fixes:
  * make -F option as default for alsactl
  * fix iecset index range
  * fix a bug in alsactl restore that restores wrong values
* Mon Nov 12 2007 tiwai@suse.de
- fix double entries of comment.tlv in alsactl (#340516)
* Mon Nov  5 2007 tiwai@suse.de
- fix speaker-test with pulse plugin output
- use stderr for error message from speaker-test
* Mon Oct 29 2007 tiwai@suse.de
- make alsactl more robust
  * restore the volume values with channel changes
  * restore from dB level if available
* Tue Oct 16 2007 tiwai@suse.de
- updated to version 1.0.15-final
  * including all previous patches
* Mon Sep 17 2007 tiwai@suse.de
- fix the handling of capture enum elements in alsamixer (#325677)
* Tue Aug 14 2007 tiwai@suse.de
- amixer - Allow to pass enum item string for cset, too
- aplay - Include missing time.h for time()
* Mon Jul 30 2007 tiwai@suse.de
- HG fixes (as of 2007.07.28)
  * don't install hwcfg file for openSUSE 10.3 in alsaconf
  * fix the handling of enum channels in amixer
  * fix VU meter of aplay
  * fix possible infinite loop with signal handler in aplay
* Thu May 31 2007 tiwai@suse.de
- updated to version 1.0.14-final
  including previous HG fixes
* Thu May 24 2007 tiwai@suse.de
- HG patch as of 2007.05.24:
  * more error verbose messages in alsactl
  * fix duplicated mixer elements in alsamixer
- Use find_lang
* Wed May  2 2007 tiwai@suse.de
- updated to version 1.0.14rc4
  including HG fixes
* Mon Apr 16 2007 tiwai@suse.de
- split from alsa package
